@@ -1,9 +1,9 @@
 package Text::ANSITable;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
+our $DATE = '2020-06-21'; # DATE
 our $DIST = 'Text-ANSITable'; # DIST
-our $VERSION = '0.599_001'; # TRIAL VERSION
+our $VERSION = '0.599_002'; # TRIAL VERSION
 
 use 5.010001;
 use Carp;
@@ -1489,14 +1489,13 @@ sub _get_data_cell_lines {
     my $tmp;
     my $fgcolor;
     if (defined ($tmp = $self->get_eff_cell_style($oy, $x, 'fgcolor'))) {
-        say "D0";
-        $fgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args);
+        $fgcolor = item_color_to_ansi($tmp);
     } elsif (defined ($tmp = $self->get_eff_row_style($oy, 'fgcolor'))) {
-        $fgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args);
+        $fgcolor = item_color_to_ansi($tmp);
     } elsif (defined ($tmp = $self->get_eff_column_style($x, 'fgcolor'))) {
-        $fgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args);
+        $fgcolor = item_color_to_ansi($tmp);
     } elsif (defined ($tmp = $self->{cell_fgcolor})) {
-        $fgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args);
+        $fgcolor = item_color_to_ansi($tmp);
     } elsif (defined ($tmp = $self->{_draw}{fcol_detect}[$x]{fgcolor})) {
         $fgcolor = item_color_to_ansi($tmp);
     } elsif ($tmp = $self->_color_theme_item_color_to_ansi('cell', $args)) {
@@ -1507,13 +1506,13 @@ sub _get_data_cell_lines {
 
     my $bgcolor;
     if (defined ($tmp = $self->get_eff_cell_style($oy, $x, 'bgcolor'))) {
-        $bgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args, 'bg');
+        $bgcolor = item_color_to_ansi($tmp, 'bg');
     } elsif (defined ($tmp = $self->get_eff_row_style($oy, 'bgcolor'))) {
-        $bgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args, 'bg');
+        $bgcolor = item_color_to_ansi($tmp, 'bg');
     } elsif (defined ($tmp = $self->get_eff_column_style($x, 'bgcolor'))) {
-        $bgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args, 'bg');
+        $bgcolor = item_color_to_ansi($tmp, 'bg');
     } elsif (defined ($tmp = $self->{cell_bgcolor})) {
-        $bgcolor = $self->_color_theme_item_color_to_ansi($tmp, $args, 'bg');
+        $bgcolor = item_color_to_ansi($tmp, 'bg');
     } elsif (defined ($tmp = $self->{_draw}{fcol_detect}[$x]{bgcolor})) {
         $bgcolor = item_color_to_ansi($tmp, 'bg');
     } elsif ($tmp = $self->_color_theme_item_color_to_ansi('cell_bg', $args, 'bg')) {
@@ -1715,7 +1714,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.599_001 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2020-06-19.
+This document describes version 0.599_002 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2020-06-21.
 
 =head1 SYNOPSIS
 
